import typing

import java
import java.chaquopy
import java.io
import java.lang
import java.time
import java.util

class ZoneOffsetTransition(java.io.Serializable, java.lang.Comparable[ZoneOffsetTransition]):
    def compareTo(self, transition: ZoneOffsetTransition, /) -> int: ...
    def equals(self, other: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def getDateTimeAfter(self) -> java.time.LocalDateTime: ...
    def getDateTimeBefore(self) -> java.time.LocalDateTime: ...
    def getDuration(self) -> java.time.Duration: ...
    def getInstant(self) -> java.time.Instant: ...
    def getOffsetAfter(self) -> java.time.ZoneOffset: ...
    def getOffsetBefore(self) -> java.time.ZoneOffset: ...
    def hashCode(self) -> int: ...
    def isGap(self) -> bool: ...
    def isOverlap(self) -> bool: ...
    def isValidOffset(self, offset: java.time.ZoneOffset, /) -> bool: ...
    @staticmethod
    def of(transition: java.time.LocalDateTime, offsetBefore: java.time.ZoneOffset, offsetAfter: java.time.ZoneOffset, /) -> ZoneOffsetTransition: ...
    def toEpochSecond(self) -> int: ...
    def toString(self) -> str: ...

class ZoneOffsetTransitionRule(java.io.Serializable):
    def createTransition(self, year: int | java.jint | java.lang.Integer, /) -> ZoneOffsetTransition: ...
    def equals(self, otherRule: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def getDayOfMonthIndicator(self) -> int: ...
    def getDayOfWeek(self) -> java.time.DayOfWeek: ...
    def getLocalTime(self) -> java.time.LocalTime: ...
    def getMonth(self) -> java.time.Month: ...
    def getOffsetAfter(self) -> java.time.ZoneOffset: ...
    def getOffsetBefore(self) -> java.time.ZoneOffset: ...
    def getStandardOffset(self) -> java.time.ZoneOffset: ...
    def getTimeDefinition(self) -> ZoneOffsetTransitionRule.TimeDefinition: ...
    def hashCode(self) -> int: ...
    def isMidnightEndOfDay(self) -> bool: ...
    @staticmethod
    def of(month: java.time.Month, dayOfMonthIndicator: int | java.jint | java.lang.Integer, dayOfWeek: java.time.DayOfWeek, time: java.time.LocalTime, timeEndOfDay: bool | java.jboolean | java.lang.Boolean, timeDefinition: ZoneOffsetTransitionRule.TimeDefinition, standardOffset: java.time.ZoneOffset, offsetBefore: java.time.ZoneOffset, offsetAfter: java.time.ZoneOffset, /) -> ZoneOffsetTransitionRule: ...
    def toString(self) -> str: ...

    class TimeDefinition(java.lang.Enum[ZoneOffsetTransitionRule.TimeDefinition]):
        STANDARD: typing.ClassVar[ZoneOffsetTransitionRule.TimeDefinition] = ...
        UTC: typing.ClassVar[ZoneOffsetTransitionRule.TimeDefinition] = ...
        WALL: typing.ClassVar[ZoneOffsetTransitionRule.TimeDefinition] = ...
        def createDateTime(self, dateTime: java.time.LocalDateTime, standardOffset: java.time.ZoneOffset, wallOffset: java.time.ZoneOffset, /) -> java.time.LocalDateTime: ...
        @staticmethod
        def valueOf(name: str | java.lang.String, /) -> ZoneOffsetTransitionRule.TimeDefinition: ...
        @staticmethod
        def values() -> java.chaquopy.JavaArray[ZoneOffsetTransitionRule.TimeDefinition]: ...

class ZoneRules(java.io.Serializable):
    def equals(self, otherRules: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def getDaylightSavings(self, instant: java.time.Instant, /) -> java.time.Duration: ...
    @typing.overload
    def getOffset(self, instant: java.time.Instant, /) -> java.time.ZoneOffset: ...
    @typing.overload
    def getOffset(self, localDateTime: java.time.LocalDateTime, /) -> java.time.ZoneOffset: ...
    def getStandardOffset(self, instant: java.time.Instant, /) -> java.time.ZoneOffset: ...
    def getTransition(self, localDateTime: java.time.LocalDateTime, /) -> ZoneOffsetTransition: ...
    def getTransitionRules(self) -> java.util.List[ZoneOffsetTransitionRule]: ...
    def getTransitions(self) -> java.util.List[ZoneOffsetTransition]: ...
    def getValidOffsets(self, localDateTime: java.time.LocalDateTime, /) -> java.util.List[java.time.ZoneOffset]: ...
    def hashCode(self) -> int: ...
    def isDaylightSavings(self, instant: java.time.Instant, /) -> bool: ...
    def isFixedOffset(self) -> bool: ...
    def isValidOffset(self, localDateTime: java.time.LocalDateTime, offset: java.time.ZoneOffset, /) -> bool: ...
    def nextTransition(self, instant: java.time.Instant, /) -> ZoneOffsetTransition: ...
    @typing.overload
    @staticmethod
    def of(offset: java.time.ZoneOffset, /) -> ZoneRules: ...
    @typing.overload
    @staticmethod
    def of(baseStandardOffset: java.time.ZoneOffset, baseWallOffset: java.time.ZoneOffset, standardOffsetTransitionList: java.util.List[ZoneOffsetTransition], transitionList: java.util.List[ZoneOffsetTransition], lastRules: java.util.List[ZoneOffsetTransitionRule], /) -> ZoneRules: ...
    def previousTransition(self, instant: java.time.Instant, /) -> ZoneOffsetTransition: ...
    def toString(self) -> str: ...

class ZoneRulesException(java.time.DateTimeException):
    @typing.overload
    def __init__(self, message: str | java.lang.String, /) -> None: ...
    @typing.overload
    def __init__(self, message: str | java.lang.String, cause: java.lang.Throwable, /) -> None: ...



import android.content
import android.location
import java.lang

class AltitudeConverter(java.lang.Object):
    def __init__(self) -> None: ...
    def addMslAltitudeToLocation(self, context: android.content.Context, location: android.location.Location, /) -> None: ...
    def tryAddMslAltitudeToLocation(self, location: android.location.Location, /) -> bool: ...



import typing

import android.os
import android.view
import java
import java.chaquopy
import java.lang
import java.util
import java.util.concurrent

class DeviceProductInfo(android.os.Parcelable):
    CONNECTION_TO_SINK_BUILT_IN: typing.ClassVar[int] = ...
    CONNECTION_TO_SINK_DIRECT: typing.ClassVar[int] = ...
    CONNECTION_TO_SINK_TRANSITIVE: typing.ClassVar[int] = ...
    CONNECTION_TO_SINK_UNKNOWN: typing.ClassVar[int] = ...
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[DeviceProductInfo]] = ...
    def __init__(self, name: str | java.lang.String, manufacturerPnpId: str | java.lang.String, productId: str | java.lang.String, modelYear: int | java.jint | java.lang.Integer, connectionToSinkType: int | java.jint | java.lang.Integer, /) -> None: ...
    def describeContents(self) -> int: ...
    def equals(self, o: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def getConnectionToSinkType(self) -> int: ...
    def getManufactureWeek(self) -> int: ...
    def getManufactureYear(self) -> int: ...
    def getManufacturerPnpId(self) -> str: ...
    def getModelYear(self) -> int: ...
    def getName(self) -> str | None: ...
    def getProductId(self) -> str: ...
    def hashCode(self) -> int: ...
    def toString(self) -> str: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

class DisplayManager(java.lang.Object):
    DISPLAY_CATEGORY_PRESENTATION: typing.ClassVar[str] = ...
    EVENT_TYPE_DISPLAY_ADDED: typing.ClassVar[int] = ...
    EVENT_TYPE_DISPLAY_CHANGED: typing.ClassVar[int] = ...
    EVENT_TYPE_DISPLAY_REFRESH_RATE: typing.ClassVar[int] = ...
    EVENT_TYPE_DISPLAY_REMOVED: typing.ClassVar[int] = ...
    EVENT_TYPE_DISPLAY_STATE: typing.ClassVar[int] = ...
    MATCH_CONTENT_FRAMERATE_ALWAYS: typing.ClassVar[int] = ...
    MATCH_CONTENT_FRAMERATE_NEVER: typing.ClassVar[int] = ...
    MATCH_CONTENT_FRAMERATE_SEAMLESSS_ONLY: typing.ClassVar[int] = ...
    MATCH_CONTENT_FRAMERATE_UNKNOWN: typing.ClassVar[int] = ...
    VIRTUAL_DISPLAY_FLAG_AUTO_MIRROR: typing.ClassVar[int] = ...
    VIRTUAL_DISPLAY_FLAG_OWN_CONTENT_ONLY: typing.ClassVar[int] = ...
    VIRTUAL_DISPLAY_FLAG_PRESENTATION: typing.ClassVar[int] = ...
    VIRTUAL_DISPLAY_FLAG_PUBLIC: typing.ClassVar[int] = ...
    VIRTUAL_DISPLAY_FLAG_SECURE: typing.ClassVar[int] = ...
    @typing.overload
    def createVirtualDisplay(self, config: VirtualDisplayConfig, /) -> VirtualDisplay | None: ...
    @typing.overload
    def createVirtualDisplay(self, config: VirtualDisplayConfig, handler: android.os.Handler, callback: VirtualDisplay.Callback, /) -> VirtualDisplay | None: ...
    @typing.overload
    def createVirtualDisplay(self, name: str | java.lang.String, width: int | java.jint | java.lang.Integer, height: int | java.jint | java.lang.Integer, densityDpi: int | java.jint | java.lang.Integer, surface: android.view.Surface, flags: int | java.jint | java.lang.Integer, /) -> VirtualDisplay | None: ...
    @typing.overload
    def createVirtualDisplay(self, name: str | java.lang.String, width: int | java.jint | java.lang.Integer, height: int | java.jint | java.lang.Integer, densityDpi: int | java.jint | java.lang.Integer, surface: android.view.Surface, flags: int | java.jint | java.lang.Integer, callback: VirtualDisplay.Callback, handler: android.os.Handler, /) -> VirtualDisplay | None: ...
    def getDisplay(self, displayId: int | java.jint | java.lang.Integer, /) -> android.view.Display | None: ...
    @typing.overload
    def getDisplays(self) -> java.chaquopy.JavaArray[android.view.Display]: ...
    @typing.overload
    def getDisplays(self, category: str | java.lang.String, /) -> java.chaquopy.JavaArray[android.view.Display]: ...
    def getHdrConversionMode(self) -> HdrConversionMode: ...
    def getMatchContentFrameRateUserPreference(self) -> int: ...
    @typing.overload
    def registerDisplayListener(self, listener: DisplayManager.DisplayListener, handler: android.os.Handler, /) -> None: ...
    @typing.overload
    def registerDisplayListener(self, executor: java.util.concurrent.Executor, eventFilter: int | java.jlong | java.lang.Long, listener: DisplayManager.DisplayListener, /) -> None: ...
    def unregisterDisplayListener(self, listener: DisplayManager.DisplayListener, /) -> None: ...

    class DisplayListener(java.lang.Object):
        def onDisplayAdded(self, arg1: int | java.jint | java.lang.Integer, /) -> None: ...
        def onDisplayChanged(self, arg1: int | java.jint | java.lang.Integer, /) -> None: ...
        def onDisplayRemoved(self, arg1: int | java.jint | java.lang.Integer, /) -> None: ...

class HdrConversionMode(android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[HdrConversionMode]] = ...
    HDR_CONVERSION_FORCE: typing.ClassVar[int] = ...
    HDR_CONVERSION_PASSTHROUGH: typing.ClassVar[int] = ...
    HDR_CONVERSION_SYSTEM: typing.ClassVar[int] = ...
    HDR_CONVERSION_UNSUPPORTED: typing.ClassVar[int] = ...
    @typing.overload
    def __init__(self, conversionMode: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def __init__(self, conversionMode: int | java.jint | java.lang.Integer, preferredHdrOutputType: int | java.jint | java.lang.Integer, /) -> None: ...
    def describeContents(self) -> int: ...
    def equals(self, o: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def getConversionMode(self) -> int: ...
    def getPreferredHdrOutputType(self) -> int: ...
    def hashCode(self) -> int: ...
    def toString(self) -> str: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

class VirtualDisplay(java.lang.Object):
    def getDisplay(self) -> android.view.Display: ...
    def getSurface(self) -> android.view.Surface: ...
    def release(self) -> None: ...
    def resize(self, width: int | java.jint | java.lang.Integer, height: int | java.jint | java.lang.Integer, densityDpi: int | java.jint | java.lang.Integer, /) -> None: ...
    def setRotation(self, rotation: int | java.jint | java.lang.Integer, /) -> None: ...
    def setSurface(self, surface: android.view.Surface, /) -> None: ...
    def toString(self) -> str: ...

    class Callback(java.lang.Object):
        def __init__(self) -> None: ...
        def onPaused(self) -> None: ...
        def onResumed(self) -> None: ...
        def onStopped(self) -> None: ...

class VirtualDisplayConfig(android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[VirtualDisplayConfig]] = ...
    def describeContents(self) -> int: ...
    def equals(self, o: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def getDefaultBrightness(self) -> float: ...
    def getDensityDpi(self) -> int: ...
    def getDimBrightness(self) -> float: ...
    def getDisplayCategories(self) -> java.util.Set[java.lang.String]: ...
    def getFlags(self) -> int: ...
    def getHeight(self) -> int: ...
    def getName(self) -> str: ...
    def getRequestedRefreshRate(self) -> float: ...
    def getSurface(self) -> android.view.Surface | None: ...
    def getWidth(self) -> int: ...
    def hashCode(self) -> int: ...
    def toString(self) -> str: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

    class Builder(java.lang.Object):
        def __init__(self, name: str | java.lang.String, width: int | java.jint | java.lang.Integer, height: int | java.jint | java.lang.Integer, densityDpi: int | java.jint | java.lang.Integer, /) -> None: ...
        def addDisplayCategory(self, displayCategory: str | java.lang.String, /) -> VirtualDisplayConfig.Builder: ...
        def build(self) -> VirtualDisplayConfig: ...
        def setBrightnessListener(self, executor: java.util.concurrent.Executor, listener: VirtualDisplayConfig.BrightnessListener, /) -> VirtualDisplayConfig.Builder: ...
        def setDefaultBrightness(self, brightness: float | java.jfloat | java.lang.Float, /) -> VirtualDisplayConfig.Builder: ...
        def setDimBrightness(self, brightness: float | java.jfloat | java.lang.Float, /) -> VirtualDisplayConfig.Builder: ...
        def setDisplayCategories(self, displayCategories: java.util.Set[java.lang.String], /) -> VirtualDisplayConfig.Builder: ...
        def setFlags(self, flags: int | java.jint | java.lang.Integer, /) -> VirtualDisplayConfig.Builder: ...
        def setRequestedRefreshRate(self, requestedRefreshRate: float | java.jfloat | java.lang.Float, /) -> VirtualDisplayConfig.Builder: ...
        def setSurface(self, surface: android.view.Surface, /) -> VirtualDisplayConfig.Builder: ...

    class BrightnessListener(java.lang.Object):
        def onBrightnessChanged(self, arg1: float | java.jfloat | java.lang.Float, /) -> None: ...



import typing

import android.animation
import android.content
import android.graphics
import android.util
import android.view
import java
import java.chaquopy
import java.lang
import java.util

class ArcMotion(PathMotion):
    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, context: android.content.Context, attrs: android.util.AttributeSet, /) -> None: ...
    def getMaximumAngle(self) -> float: ...
    def getMinimumHorizontalAngle(self) -> float: ...
    def getMinimumVerticalAngle(self) -> float: ...
    def getPath(self, startX: float | java.jfloat | java.lang.Float, startY: float | java.jfloat | java.lang.Float, endX: float | java.jfloat | java.lang.Float, endY: float | java.jfloat | java.lang.Float, /) -> android.graphics.Path: ...
    def setMaximumAngle(self, angleInDegrees: float | java.jfloat | java.lang.Float, /) -> None: ...
    def setMinimumHorizontalAngle(self, angleInDegrees: float | java.jfloat | java.lang.Float, /) -> None: ...
    def setMinimumVerticalAngle(self, angleInDegrees: float | java.jfloat | java.lang.Float, /) -> None: ...

class AutoTransition(TransitionSet):
    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, context: android.content.Context, attrs: android.util.AttributeSet, /) -> None: ...

class ChangeBounds(Transition):
    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, context: android.content.Context, attrs: android.util.AttributeSet, /) -> None: ...
    def captureEndValues(self, transitionValues: TransitionValues, /) -> None: ...
    def captureStartValues(self, transitionValues: TransitionValues, /) -> None: ...
    def createAnimator(self, sceneRoot: android.view.ViewGroup, startValues: TransitionValues, endValues: TransitionValues, /) -> android.animation.Animator | None: ...
    def getResizeClip(self) -> bool: ...
    def getTransitionProperties(self) -> java.chaquopy.JavaArray[java.lang.String]: ...
    def setReparent(self, reparent: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setResizeClip(self, resizeClip: bool | java.jboolean | java.lang.Boolean, /) -> None: ...

class ChangeClipBounds(Transition):
    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, context: android.content.Context, attrs: android.util.AttributeSet, /) -> None: ...
    def captureEndValues(self, transitionValues: TransitionValues, /) -> None: ...
    def captureStartValues(self, transitionValues: TransitionValues, /) -> None: ...
    def createAnimator(self, sceneRoot: android.view.ViewGroup, startValues: TransitionValues, endValues: TransitionValues, /) -> android.animation.Animator | None: ...
    def getTransitionProperties(self) -> java.chaquopy.JavaArray[java.lang.String]: ...

class ChangeImageTransform(Transition):
    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, context: android.content.Context, attrs: android.util.AttributeSet, /) -> None: ...
    def captureEndValues(self, transitionValues: TransitionValues, /) -> None: ...
    def captureStartValues(self, transitionValues: TransitionValues, /) -> None: ...
    def createAnimator(self, sceneRoot: android.view.ViewGroup, startValues: TransitionValues, endValues: TransitionValues, /) -> android.animation.Animator | None: ...
    def getTransitionProperties(self) -> java.chaquopy.JavaArray[java.lang.String]: ...

class ChangeScroll(Transition):
    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, context: android.content.Context, attrs: android.util.AttributeSet, /) -> None: ...
    def captureEndValues(self, transitionValues: TransitionValues, /) -> None: ...
    def captureStartValues(self, transitionValues: TransitionValues, /) -> None: ...
    def createAnimator(self, sceneRoot: android.view.ViewGroup, startValues: TransitionValues, endValues: TransitionValues, /) -> android.animation.Animator | None: ...
    def getTransitionProperties(self) -> java.chaquopy.JavaArray[java.lang.String]: ...

class ChangeTransform(Transition):
    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, context: android.content.Context, attrs: android.util.AttributeSet, /) -> None: ...
    def captureEndValues(self, transitionValues: TransitionValues, /) -> None: ...
    def captureStartValues(self, transitionValues: TransitionValues, /) -> None: ...
    def createAnimator(self, sceneRoot: android.view.ViewGroup, startValues: TransitionValues, endValues: TransitionValues, /) -> android.animation.Animator | None: ...
    def getReparent(self) -> bool: ...
    def getReparentWithOverlay(self) -> bool: ...
    def getTransitionProperties(self) -> java.chaquopy.JavaArray[java.lang.String]: ...
    def setReparent(self, reparent: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setReparentWithOverlay(self, reparentWithOverlay: bool | java.jboolean | java.lang.Boolean, /) -> None: ...

class CircularPropagation(VisibilityPropagation):
    def __init__(self) -> None: ...
    def getStartDelay(self, sceneRoot: android.view.ViewGroup, transition: Transition, startValues: TransitionValues, endValues: TransitionValues, /) -> int: ...
    def setPropagationSpeed(self, propagationSpeed: float | java.jfloat | java.lang.Float, /) -> None: ...

class Explode(Visibility):
    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, context: android.content.Context, attrs: android.util.AttributeSet, /) -> None: ...
    def captureEndValues(self, transitionValues: TransitionValues, /) -> None: ...
    def captureStartValues(self, transitionValues: TransitionValues, /) -> None: ...
    def onAppear(self, sceneRoot: android.view.ViewGroup, view: android.view.View, startValues: TransitionValues, endValues: TransitionValues, /) -> android.animation.Animator: ...
    def onDisappear(self, sceneRoot: android.view.ViewGroup, view: android.view.View, startValues: TransitionValues, endValues: TransitionValues, /) -> android.animation.Animator: ...

class Fade(Visibility):
    IN: typing.ClassVar[int] = ...
    OUT: typing.ClassVar[int] = ...
    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, fadingMode: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def __init__(self, context: android.content.Context, attrs: android.util.AttributeSet, /) -> None: ...
    def captureStartValues(self, transitionValues: TransitionValues, /) -> None: ...
    def onAppear(self, sceneRoot: android.view.ViewGroup, view: android.view.View, startValues: TransitionValues, endValues: TransitionValues, /) -> android.animation.Animator: ...
    def onDisappear(self, sceneRoot: android.view.ViewGroup, view: android.view.View, startValues: TransitionValues, endValues: TransitionValues, /) -> android.animation.Animator: ...

class PathMotion(java.lang.Object):
    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, context: android.content.Context, attrs: android.util.AttributeSet, /) -> None: ...
    def getPath(self, arg1: float | java.jfloat | java.lang.Float, arg2: float | java.jfloat | java.lang.Float, arg3: float | java.jfloat | java.lang.Float, arg4: float | java.jfloat | java.lang.Float, /) -> android.graphics.Path: ...

class PatternPathMotion(PathMotion):
    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, patternPath: android.graphics.Path, /) -> None: ...
    @typing.overload
    def __init__(self, context: android.content.Context, attrs: android.util.AttributeSet, /) -> None: ...
    def getPath(self, startX: float | java.jfloat | java.lang.Float, startY: float | java.jfloat | java.lang.Float, endX: float | java.jfloat | java.lang.Float, endY: float | java.jfloat | java.lang.Float, /) -> android.graphics.Path: ...
    def getPatternPath(self) -> android.graphics.Path: ...
    def setPatternPath(self, patternPath: android.graphics.Path, /) -> None: ...

class Scene(java.lang.Object):
    @typing.overload
    def __init__(self, sceneRoot: android.view.ViewGroup, /) -> None: ...
    @typing.overload
    def __init__(self, sceneRoot: android.view.ViewGroup, layout: android.view.View, /) -> None: ...
    @typing.overload
    def __init__(self, sceneRoot: android.view.ViewGroup, layout: android.view.ViewGroup, /) -> None: ...
    def enter(self) -> None: ...
    def exit(self) -> None: ...
    @staticmethod
    def getCurrentScene(sceneRoot: android.view.ViewGroup, /) -> Scene | None: ...
    @staticmethod
    def getSceneForLayout(sceneRoot: android.view.ViewGroup, layoutId: int | java.jint | java.lang.Integer, context: android.content.Context, /) -> Scene: ...
    def getSceneRoot(self) -> android.view.ViewGroup: ...
    def setEnterAction(self, action: java.lang.Runnable, /) -> None: ...
    def setExitAction(self, action: java.lang.Runnable, /) -> None: ...

class SidePropagation(VisibilityPropagation):
    def __init__(self) -> None: ...
    def getStartDelay(self, sceneRoot: android.view.ViewGroup, transition: Transition, startValues: TransitionValues, endValues: TransitionValues, /) -> int: ...
    def setPropagationSpeed(self, propagationSpeed: float | java.jfloat | java.lang.Float, /) -> None: ...
    def setSide(self, side: int | java.jint | java.lang.Integer, /) -> None: ...

class Slide(Visibility):
    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, slideEdge: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def __init__(self, context: android.content.Context, attrs: android.util.AttributeSet, /) -> None: ...
    def captureEndValues(self, transitionValues: TransitionValues, /) -> None: ...
    def captureStartValues(self, transitionValues: TransitionValues, /) -> None: ...
    def getSlideEdge(self) -> int: ...
    def onAppear(self, sceneRoot: android.view.ViewGroup, view: android.view.View, startValues: TransitionValues, endValues: TransitionValues, /) -> android.animation.Animator: ...
    def onDisappear(self, sceneRoot: android.view.ViewGroup, view: android.view.View, startValues: TransitionValues, endValues: TransitionValues, /) -> android.animation.Animator: ...
    def setSlideEdge(self, slideEdge: int | java.jint | java.lang.Integer, /) -> None: ...

class Transition(java.lang.Cloneable):
    MATCH_ID: typing.ClassVar[int] = ...
    MATCH_INSTANCE: typing.ClassVar[int] = ...
    MATCH_ITEM_ID: typing.ClassVar[int] = ...
    MATCH_NAME: typing.ClassVar[int] = ...
    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, context: android.content.Context, attrs: android.util.AttributeSet, /) -> None: ...
    def addListener(self, listener: Transition.TransitionListener, /) -> Transition: ...
    @typing.overload
    def addTarget(self, targetId: int | java.jint | java.lang.Integer, /) -> Transition: ...
    @typing.overload
    def addTarget(self, target: android.view.View, /) -> Transition: ...
    @typing.overload
    def addTarget(self, targetType: typing.Type, /) -> Transition: ...
    @typing.overload
    def addTarget(self, targetName: str | java.lang.String, /) -> Transition: ...
    def canRemoveViews(self) -> bool: ...
    def captureEndValues(self, arg1: TransitionValues, /) -> None: ...
    def captureStartValues(self, arg1: TransitionValues, /) -> None: ...
    def clone(self) -> Transition: ...
    def createAnimator(self, sceneRoot: android.view.ViewGroup, startValues: TransitionValues, endValues: TransitionValues, /) -> android.animation.Animator | None: ...
    @typing.overload
    def excludeChildren(self, targetId: int | java.jint | java.lang.Integer, exclude: bool | java.jboolean | java.lang.Boolean, /) -> Transition: ...
    @typing.overload
    def excludeChildren(self, target: android.view.View, exclude: bool | java.jboolean | java.lang.Boolean, /) -> Transition: ...
    @typing.overload
    def excludeChildren(self, type: typing.Type, exclude: bool | java.jboolean | java.lang.Boolean, /) -> Transition: ...
    @typing.overload
    def excludeTarget(self, targetId: int | java.jint | java.lang.Integer, exclude: bool | java.jboolean | java.lang.Boolean, /) -> Transition: ...
    @typing.overload
    def excludeTarget(self, target: android.view.View, exclude: bool | java.jboolean | java.lang.Boolean, /) -> Transition: ...
    @typing.overload
    def excludeTarget(self, type: typing.Type, exclude: bool | java.jboolean | java.lang.Boolean, /) -> Transition: ...
    @typing.overload
    def excludeTarget(self, targetName: str | java.lang.String, exclude: bool | java.jboolean | java.lang.Boolean, /) -> Transition: ...
    def getDuration(self) -> int: ...
    def getEpicenter(self) -> android.graphics.Rect: ...
    def getEpicenterCallback(self) -> Transition.EpicenterCallback: ...
    def getInterpolator(self) -> android.animation.TimeInterpolator | None: ...
    def getName(self) -> str: ...
    def getPathMotion(self) -> PathMotion: ...
    def getPropagation(self) -> TransitionPropagation: ...
    def getStartDelay(self) -> int: ...
    def getTargetIds(self) -> java.util.List[java.lang.Integer]: ...
    def getTargetNames(self) -> java.util.List[java.lang.String]: ...
    def getTargetTypes(self) -> java.util.List[typing.Type]: ...
    def getTargets(self) -> java.util.List[android.view.View]: ...
    def getTransitionProperties(self) -> java.chaquopy.JavaArray[java.lang.String]: ...
    def getTransitionValues(self, view: android.view.View, start: bool | java.jboolean | java.lang.Boolean, /) -> TransitionValues: ...
    def isTransitionRequired(self, startValues: TransitionValues, endValues: TransitionValues, /) -> bool: ...
    def removeListener(self, listener: Transition.TransitionListener, /) -> Transition: ...
    @typing.overload
    def removeTarget(self, targetId: int | java.jint | java.lang.Integer, /) -> Transition: ...
    @typing.overload
    def removeTarget(self, target: android.view.View, /) -> Transition: ...
    @typing.overload
    def removeTarget(self, target: typing.Type, /) -> Transition: ...
    @typing.overload
    def removeTarget(self, targetName: str | java.lang.String, /) -> Transition: ...
    def setDuration(self, duration: int | java.jlong | java.lang.Long, /) -> Transition: ...
    def setEpicenterCallback(self, epicenterCallback: Transition.EpicenterCallback, /) -> None: ...
    def setInterpolator(self, interpolator: android.animation.TimeInterpolator, /) -> Transition: ...
    def setMatchOrder(self, *matches: java.jint) -> None: ...
    def setPathMotion(self, pathMotion: PathMotion, /) -> None: ...
    def setPropagation(self, transitionPropagation: TransitionPropagation, /) -> None: ...
    def setStartDelay(self, startDelay: int | java.jlong | java.lang.Long, /) -> Transition: ...
    def toString(self) -> str: ...

    class TransitionListener(java.lang.Object):
        def onTransitionCancel(self, arg1: Transition, /) -> None: ...
        def onTransitionEnd(self, arg1: Transition, /) -> None: ...
        def onTransitionPause(self, arg1: Transition, /) -> None: ...
        def onTransitionResume(self, arg1: Transition, /) -> None: ...
        def onTransitionStart(self, arg1: Transition, /) -> None: ...

    class EpicenterCallback(java.lang.Object):
        def __init__(self) -> None: ...
        def onGetEpicenter(self, arg1: Transition, /) -> android.graphics.Rect: ...

class TransitionInflater(java.lang.Object):
    @staticmethod
    def from_(context: android.content.Context, /) -> TransitionInflater: ...
    def inflateTransition(self, resource: int | java.jint | java.lang.Integer, /) -> Transition: ...
    def inflateTransitionManager(self, resource: int | java.jint | java.lang.Integer, sceneRoot: android.view.ViewGroup, /) -> TransitionManager: ...

class TransitionListenerAdapter(Transition.TransitionListener):
    def __init__(self) -> None: ...
    def onTransitionCancel(self, transition: Transition, /) -> None: ...
    def onTransitionEnd(self, transition: Transition, /) -> None: ...
    def onTransitionPause(self, transition: Transition, /) -> None: ...
    def onTransitionResume(self, transition: Transition, /) -> None: ...
    def onTransitionStart(self, transition: Transition, /) -> None: ...

class TransitionManager(java.lang.Object):
    def __init__(self) -> None: ...
    @typing.overload
    @staticmethod
    def beginDelayedTransition(sceneRoot: android.view.ViewGroup, /) -> None: ...
    @typing.overload
    @staticmethod
    def beginDelayedTransition(sceneRoot: android.view.ViewGroup, transition: Transition, /) -> None: ...
    @staticmethod
    def endTransitions(sceneRoot: android.view.ViewGroup, /) -> None: ...
    @typing.overload
    @staticmethod
    def go(scene: Scene, /) -> None: ...
    @typing.overload
    @staticmethod
    def go(scene: Scene, transition: Transition, /) -> None: ...
    @typing.overload
    def setTransition(self, scene: Scene, transition: Transition, /) -> None: ...
    @typing.overload
    def setTransition(self, fromScene: Scene, toScene: Scene, transition: Transition, /) -> None: ...
    def transitionTo(self, scene: Scene, /) -> None: ...

class TransitionPropagation(java.lang.Object):
    def __init__(self) -> None: ...
    def captureValues(self, arg1: TransitionValues, /) -> None: ...
    def getPropagationProperties(self) -> java.chaquopy.JavaArray[java.lang.String]: ...
    def getStartDelay(self, arg1: android.view.ViewGroup, arg2: Transition, arg3: TransitionValues, arg4: TransitionValues, /) -> int: ...

class TransitionSet(Transition):
    ORDERING_SEQUENTIAL: typing.ClassVar[int] = ...
    ORDERING_TOGETHER: typing.ClassVar[int] = ...
    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, context: android.content.Context, attrs: android.util.AttributeSet, /) -> None: ...
    def addListener(self, listener: Transition.TransitionListener, /) -> TransitionSet: ...
    @typing.overload
    def addTarget(self, targetId: int | java.jint | java.lang.Integer, /) -> TransitionSet: ...
    @typing.overload
    def addTarget(self, target: android.view.View, /) -> TransitionSet: ...
    @typing.overload
    def addTarget(self, targetType: typing.Type, /) -> TransitionSet: ...
    @typing.overload
    def addTarget(self, targetName: str | java.lang.String, /) -> TransitionSet: ...
    def addTransition(self, transition: Transition, /) -> TransitionSet: ...
    def captureEndValues(self, transitionValues: TransitionValues, /) -> None: ...
    def captureStartValues(self, transitionValues: TransitionValues, /) -> None: ...
    def clone(self) -> TransitionSet: ...
    @typing.overload
    def excludeTarget(self, targetId: int | java.jint | java.lang.Integer, exclude: bool | java.jboolean | java.lang.Boolean, /) -> Transition: ...
    @typing.overload
    def excludeTarget(self, target: android.view.View, exclude: bool | java.jboolean | java.lang.Boolean, /) -> Transition: ...
    @typing.overload
    def excludeTarget(self, type: typing.Type, exclude: bool | java.jboolean | java.lang.Boolean, /) -> Transition: ...
    @typing.overload
    def excludeTarget(self, targetName: str | java.lang.String, exclude: bool | java.jboolean | java.lang.Boolean, /) -> Transition: ...
    def getOrdering(self) -> int: ...
    def getTransitionAt(self, index: int | java.jint | java.lang.Integer, /) -> Transition: ...
    def getTransitionCount(self) -> int: ...
    def removeListener(self, listener: Transition.TransitionListener, /) -> TransitionSet: ...
    @typing.overload
    def removeTarget(self, targetId: int | java.jint | java.lang.Integer, /) -> TransitionSet: ...
    @typing.overload
    def removeTarget(self, target: android.view.View, /) -> TransitionSet: ...
    @typing.overload
    def removeTarget(self, target: typing.Type, /) -> TransitionSet: ...
    @typing.overload
    def removeTarget(self, target: str | java.lang.String, /) -> TransitionSet: ...
    def removeTransition(self, transition: Transition, /) -> TransitionSet: ...
    def setDuration(self, duration: int | java.jlong | java.lang.Long, /) -> TransitionSet: ...
    def setEpicenterCallback(self, epicenterCallback: Transition.EpicenterCallback, /) -> None: ...
    def setInterpolator(self, interpolator: android.animation.TimeInterpolator, /) -> TransitionSet: ...
    def setOrdering(self, ordering: int | java.jint | java.lang.Integer, /) -> TransitionSet: ...
    def setPathMotion(self, pathMotion: PathMotion, /) -> None: ...
    def setPropagation(self, propagation: TransitionPropagation, /) -> None: ...
    def setStartDelay(self, startDelay: int | java.jlong | java.lang.Long, /) -> TransitionSet: ...

class TransitionValues(java.lang.Object):
    values: java.util.Map[java.lang.String, java.lang.Object] = ...
    view: android.view.View = ...
    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, view: android.view.View, /) -> None: ...
    def equals(self, other: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def hashCode(self) -> int: ...
    def toString(self) -> str: ...

class Visibility(Transition):
    MODE_IN: typing.ClassVar[int] = ...
    MODE_OUT: typing.ClassVar[int] = ...
    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, context: android.content.Context, attrs: android.util.AttributeSet, /) -> None: ...
    def captureEndValues(self, transitionValues: TransitionValues, /) -> None: ...
    def captureStartValues(self, transitionValues: TransitionValues, /) -> None: ...
    def createAnimator(self, sceneRoot: android.view.ViewGroup, startValues: TransitionValues, endValues: TransitionValues, /) -> android.animation.Animator | None: ...
    def getMode(self) -> int: ...
    def getTransitionProperties(self) -> java.chaquopy.JavaArray[java.lang.String]: ...
    def isTransitionRequired(self, startValues: TransitionValues, newValues: TransitionValues, /) -> bool: ...
    def isVisible(self, values: TransitionValues, /) -> bool: ...
    @typing.overload
    def onAppear(self, sceneRoot: android.view.ViewGroup, view: android.view.View, startValues: TransitionValues, endValues: TransitionValues, /) -> android.animation.Animator: ...
    @typing.overload
    def onAppear(self, sceneRoot: android.view.ViewGroup, startValues: TransitionValues, startVisibility: int | java.jint | java.lang.Integer, endValues: TransitionValues, endVisibility: int | java.jint | java.lang.Integer, /) -> android.animation.Animator: ...
    @typing.overload
    def onDisappear(self, sceneRoot: android.view.ViewGroup, view: android.view.View, startValues: TransitionValues, endValues: TransitionValues, /) -> android.animation.Animator: ...
    @typing.overload
    def onDisappear(self, sceneRoot: android.view.ViewGroup, startValues: TransitionValues, startVisibility: int | java.jint | java.lang.Integer, endValues: TransitionValues, endVisibility: int | java.jint | java.lang.Integer, /) -> android.animation.Animator: ...
    def setMode(self, mode: int | java.jint | java.lang.Integer, /) -> None: ...

class VisibilityPropagation(TransitionPropagation):
    def __init__(self) -> None: ...
    def captureValues(self, values: TransitionValues, /) -> None: ...
    def getPropagationProperties(self) -> java.chaquopy.JavaArray[java.lang.String]: ...
    def getViewVisibility(self, values: TransitionValues, /) -> int: ...
    def getViewX(self, values: TransitionValues, /) -> int: ...
    def getViewY(self, values: TransitionValues, /) -> int: ...



import typing

import android.net.wifi.hotspot2.pps
import android.os
import java
import java.chaquopy
import java.lang

class ConfigParser(java.lang.Object):
    @staticmethod
    def parsePasspointConfig(mimeType: str | java.lang.String, data: java.chaquopy.JavaArrayJByte, /) -> PasspointConfiguration: ...

class PasspointConfiguration(android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[PasspointConfiguration]] = ...
    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, source: PasspointConfiguration, /) -> None: ...
    def describeContents(self) -> int: ...
    def equals(self, thatObject: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def getCredential(self) -> android.net.wifi.hotspot2.pps.Credential: ...
    def getDecoratedIdentityPrefix(self) -> str | None: ...
    def getHomeSp(self) -> android.net.wifi.hotspot2.pps.HomeSp: ...
    def getSubscriptionExpirationTimeMillis(self) -> int: ...
    def getUniqueId(self) -> str: ...
    def hashCode(self) -> int: ...
    def isOsuProvisioned(self) -> bool: ...
    def setCredential(self, credential: android.net.wifi.hotspot2.pps.Credential, /) -> None: ...
    def setDecoratedIdentityPrefix(self, decoratedIdentityPrefix: str | java.lang.String, /) -> None: ...
    def setHomeSp(self, homeSp: android.net.wifi.hotspot2.pps.HomeSp, /) -> None: ...
    def setSubscriptionExpirationTimeInMillis(self, subscriptionExpirationTimeInMillis: int | java.jlong | java.lang.Long, /) -> None: ...
    def toString(self) -> str: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...



import typing

import android.content
import android.net
import android.os
import java
import java.chaquopy
import java.lang
import java.util

class DownloadProgressListener(java.lang.Object):
    def __init__(self) -> None: ...
    def onProgressUpdated(self, request: DownloadRequest, fileInfo: FileInfo, currentDownloadSize: int | java.jint | java.lang.Integer, fullDownloadSize: int | java.jint | java.lang.Integer, currentDecodedSize: int | java.jint | java.lang.Integer, fullDecodedSize: int | java.jint | java.lang.Integer, /) -> None: ...

class DownloadRequest(android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[DownloadRequest]] = ...
    def describeContents(self) -> int: ...
    def equals(self, o: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def getDestinationUri(self) -> android.net.Uri: ...
    def getFileServiceId(self) -> str: ...
    @staticmethod
    def getMaxAppIntentSize() -> int: ...
    @staticmethod
    def getMaxDestinationUriSize() -> int: ...
    def getSourceUri(self) -> android.net.Uri: ...
    def getSubscriptionId(self) -> int: ...
    def hashCode(self) -> int: ...
    def toByteArray(self) -> java.chaquopy.JavaArrayJByte: ...
    def writeToParcel(self, out: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

    class Builder(java.lang.Object):
        def __init__(self, sourceUri: android.net.Uri, destinationUri: android.net.Uri, /) -> None: ...
        def build(self) -> DownloadRequest: ...
        @staticmethod
        def fromDownloadRequest(other: DownloadRequest, /) -> DownloadRequest.Builder: ...
        @staticmethod
        def fromSerializedRequest(data: java.chaquopy.JavaArrayJByte, /) -> DownloadRequest.Builder: ...
        def setAppIntent(self, intent: android.content.Intent, /) -> DownloadRequest.Builder: ...
        def setServiceInfo(self, serviceInfo: FileServiceInfo, /) -> DownloadRequest.Builder: ...
        def setSubscriptionId(self, subscriptionId: int | java.jint | java.lang.Integer, /) -> DownloadRequest.Builder: ...

class DownloadStatusListener(java.lang.Object):
    def __init__(self) -> None: ...
    def onStatusUpdated(self, request: DownloadRequest, fileInfo: FileInfo, status: int | java.jint | java.lang.Integer, /) -> None: ...

class FileInfo(android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[FileInfo]] = ...
    def describeContents(self) -> int: ...
    def equals(self, o: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def getMimeType(self) -> str: ...
    def getUri(self) -> android.net.Uri: ...
    def hashCode(self) -> int: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

class FileServiceInfo(android.os.Parcelable, ServiceInfo):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[FileServiceInfo]] = ...
    def describeContents(self) -> int: ...
    def getFiles(self) -> java.util.List[FileInfo]: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

class GroupCall(java.lang.AutoCloseable):
    REASON_BY_USER_REQUEST: typing.ClassVar[int] = ...
    REASON_FREQUENCY_CONFLICT: typing.ClassVar[int] = ...
    REASON_LEFT_MBMS_BROADCAST_AREA: typing.ClassVar[int] = ...
    REASON_NONE: typing.ClassVar[int] = ...
    REASON_NOT_CONNECTED_TO_HOMECARRIER_LTE: typing.ClassVar[int] = ...
    REASON_OUT_OF_MEMORY: typing.ClassVar[int] = ...
    STATE_STALLED: typing.ClassVar[int] = ...
    STATE_STARTED: typing.ClassVar[int] = ...
    STATE_STOPPED: typing.ClassVar[int] = ...
    def close(self) -> None: ...
    def getTmgi(self) -> int: ...
    def updateGroupCall(self, saiList: java.util.List[java.lang.Integer], frequencyList: java.util.List[java.lang.Integer], /) -> None: ...

class GroupCallCallback(java.lang.Object):
    SIGNAL_STRENGTH_UNAVAILABLE: typing.ClassVar[int] = ...
    def onBroadcastSignalStrengthUpdated(self, signalStrength: int | java.jint | java.lang.Integer, /) -> None: ...
    def onError(self, errorCode: int | java.jint | java.lang.Integer, message: str | java.lang.String, /) -> None: ...
    def onGroupCallStateChanged(self, state: int | java.jint | java.lang.Integer, reason: int | java.jint | java.lang.Integer, /) -> None: ...

class MbmsDownloadReceiver(android.content.BroadcastReceiver):
    def __init__(self) -> None: ...
    def onReceive(self, context: android.content.Context, intent: android.content.Intent, /) -> None: ...

class MbmsDownloadSessionCallback(java.lang.Object):
    def __init__(self) -> None: ...
    def onError(self, errorCode: int | java.jint | java.lang.Integer, message: str | java.lang.String, /) -> None: ...
    def onFileServicesUpdated(self, services: java.util.List[FileServiceInfo], /) -> None: ...
    def onMiddlewareReady(self) -> None: ...

class MbmsErrors(java.lang.Object):
    ERROR_MIDDLEWARE_LOST: typing.ClassVar[int] = ...
    ERROR_MIDDLEWARE_NOT_BOUND: typing.ClassVar[int] = ...
    ERROR_NO_UNIQUE_MIDDLEWARE: typing.ClassVar[int] = ...
    SUCCESS: typing.ClassVar[int] = ...
    UNKNOWN: typing.ClassVar[int] = ...

    class StreamingErrors(java.lang.Object):
        ERROR_CONCURRENT_SERVICE_LIMIT_REACHED: typing.ClassVar[int] = ...
        ERROR_DUPLICATE_START_STREAM: typing.ClassVar[int] = ...
        ERROR_UNABLE_TO_START_SERVICE: typing.ClassVar[int] = ...

    class InitializationErrors(java.lang.Object):
        ERROR_APP_PERMISSIONS_NOT_GRANTED: typing.ClassVar[int] = ...
        ERROR_DUPLICATE_INITIALIZE: typing.ClassVar[int] = ...
        ERROR_UNABLE_TO_INITIALIZE: typing.ClassVar[int] = ...

    class GroupCallErrors(java.lang.Object):
        ERROR_DUPLICATE_START_GROUP_CALL: typing.ClassVar[int] = ...
        ERROR_UNABLE_TO_START_SERVICE: typing.ClassVar[int] = ...

    class GeneralErrors(java.lang.Object):
        ERROR_CARRIER_CHANGE_NOT_ALLOWED: typing.ClassVar[int] = ...
        ERROR_IN_E911: typing.ClassVar[int] = ...
        ERROR_MIDDLEWARE_NOT_YET_READY: typing.ClassVar[int] = ...
        ERROR_MIDDLEWARE_TEMPORARILY_UNAVAILABLE: typing.ClassVar[int] = ...
        ERROR_NOT_CONNECTED_TO_HOME_CARRIER_LTE: typing.ClassVar[int] = ...
        ERROR_OUT_OF_MEMORY: typing.ClassVar[int] = ...
        ERROR_UNABLE_TO_READ_SIM: typing.ClassVar[int] = ...

    class DownloadErrors(java.lang.Object):
        ERROR_CANNOT_CHANGE_TEMP_FILE_ROOT: typing.ClassVar[int] = ...
        ERROR_MALFORMED_SERVICE_ANNOUNCEMENT: typing.ClassVar[int] = ...
        ERROR_UNKNOWN_DOWNLOAD_REQUEST: typing.ClassVar[int] = ...
        ERROR_UNKNOWN_FILE_INFO: typing.ClassVar[int] = ...

class MbmsGroupCallSessionCallback(java.lang.Object):
    def onAvailableSaisUpdated(self, currentSais: java.util.List[java.lang.Integer], availableSais: java.util.List[java.util.List[java.lang.Integer]], /) -> None: ...
    def onError(self, errorCode: int | java.jint | java.lang.Integer, message: str | java.lang.String, /) -> None: ...
    def onMiddlewareReady(self) -> None: ...
    def onServiceInterfaceAvailable(self, interfaceName: str | java.lang.String, index: int | java.jint | java.lang.Integer, /) -> None: ...

class MbmsStreamingSessionCallback(java.lang.Object):
    def __init__(self) -> None: ...
    def onError(self, errorCode: int | java.jint | java.lang.Integer, message: str | java.lang.String, /) -> None: ...
    def onMiddlewareReady(self) -> None: ...
    def onStreamingServicesUpdated(self, services: java.util.List[StreamingServiceInfo], /) -> None: ...

class ServiceInfo(java.lang.Object):
    def equals(self, o: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def getLocales(self) -> java.util.List[java.util.Locale]: ...
    def getNameForLocale(self, locale: java.util.Locale, /) -> java.lang.CharSequence: ...
    def getNamedContentLocales(self) -> java.util.Set[java.util.Locale]: ...
    def getServiceClassName(self) -> str: ...
    def getServiceId(self) -> str: ...
    def getSessionEndTime(self) -> java.util.Date: ...
    def getSessionStartTime(self) -> java.util.Date: ...
    def hashCode(self) -> int: ...

class StreamingService(java.lang.AutoCloseable):
    BROADCAST_METHOD: typing.ClassVar[int] = ...
    REASON_BY_USER_REQUEST: typing.ClassVar[int] = ...
    REASON_END_OF_SESSION: typing.ClassVar[int] = ...
    REASON_FREQUENCY_CONFLICT: typing.ClassVar[int] = ...
    REASON_LEFT_MBMS_BROADCAST_AREA: typing.ClassVar[int] = ...
    REASON_NONE: typing.ClassVar[int] = ...
    REASON_NOT_CONNECTED_TO_HOMECARRIER_LTE: typing.ClassVar[int] = ...
    REASON_OUT_OF_MEMORY: typing.ClassVar[int] = ...
    STATE_STALLED: typing.ClassVar[int] = ...
    STATE_STARTED: typing.ClassVar[int] = ...
    STATE_STOPPED: typing.ClassVar[int] = ...
    UNICAST_METHOD: typing.ClassVar[int] = ...
    def close(self) -> None: ...
    def getInfo(self) -> StreamingServiceInfo: ...
    def getPlaybackUri(self) -> android.net.Uri | None: ...

class StreamingServiceCallback(java.lang.Object):
    SIGNAL_STRENGTH_UNAVAILABLE: typing.ClassVar[int] = ...
    def __init__(self) -> None: ...
    def onBroadcastSignalStrengthUpdated(self, signalStrength: int | java.jint | java.lang.Integer, /) -> None: ...
    def onError(self, errorCode: int | java.jint | java.lang.Integer, message: str | java.lang.String, /) -> None: ...
    def onMediaDescriptionUpdated(self) -> None: ...
    def onStreamMethodUpdated(self, methodType: int | java.jint | java.lang.Integer, /) -> None: ...
    def onStreamStateUpdated(self, state: int | java.jint | java.lang.Integer, reason: int | java.jint | java.lang.Integer, /) -> None: ...

class StreamingServiceInfo(android.os.Parcelable, ServiceInfo):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[StreamingServiceInfo]] = ...
    def describeContents(self) -> int: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...



import typing

import android.os
import java
import java.chaquopy
import java.lang

class RttRangingCapabilities(android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[RttRangingCapabilities]] = ...
    def describeContents(self) -> int: ...
    def hasPeriodicRangingHardwareFeature(self) -> bool: ...
    def toString(self) -> str: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

class RttRangingParams(android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[RttRangingParams]] = ...
    def describeContents(self) -> int: ...
    def equals(self, o: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def getMatchFilter(self) -> java.chaquopy.JavaArrayJByte: ...
    def getRangingUpdateRate(self) -> int: ...
    def getServiceName(self) -> str: ...
    def hashCode(self) -> int: ...
    def isPeriodicRangingHwFeatureEnabled(self) -> bool: ...
    def toString(self) -> str: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

    class Builder(java.lang.Object):
        def __init__(self, serviceName: str | java.lang.String, /) -> None: ...
        def build(self) -> RttRangingParams: ...
        def setMatchFilter(self, matchFilter: java.chaquopy.JavaArrayJByte, /) -> RttRangingParams.Builder: ...
        def setPeriodicRangingHwFeatureEnabled(self, periodicRangingHwFeatureEnabled: bool | java.jboolean | java.lang.Boolean, /) -> RttRangingParams.Builder: ...
        def setRangingUpdateRate(self, updateRate: int | java.jint | java.lang.Integer, /) -> RttRangingParams.Builder: ...



import typing

import android.net
import android.os
import java
import java.lang
import java.time
import java.util

class AdData(android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[AdData]] = ...
    def describeContents(self) -> int: ...
    def equals(self, o: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def getAdCounterKeys(self) -> java.util.Set[java.lang.Integer]: ...
    def getAdFilters(self) -> AdFilters | None: ...
    def getAdRenderId(self) -> str | None: ...
    def getMetadata(self) -> str: ...
    def getRenderUri(self) -> android.net.Uri: ...
    def hashCode(self) -> int: ...
    def toString(self) -> str: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

    class Builder(java.lang.Object):
        def __init__(self) -> None: ...
        def build(self) -> AdData: ...
        def setAdCounterKeys(self, adCounterKeys: java.util.Set[java.lang.Integer], /) -> AdData.Builder: ...
        def setAdFilters(self, adFilters: AdFilters, /) -> AdData.Builder: ...
        def setAdRenderId(self, adRenderId: str | java.lang.String, /) -> AdData.Builder: ...
        def setMetadata(self, metadata: str | java.lang.String, /) -> AdData.Builder: ...
        def setRenderUri(self, renderUri: android.net.Uri, /) -> AdData.Builder: ...

class AdFilters(android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[AdFilters]] = ...
    def describeContents(self) -> int: ...
    def equals(self, o: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def getAppInstallFilters(self) -> AppInstallFilters | None: ...
    def getFrequencyCapFilters(self) -> FrequencyCapFilters | None: ...
    def hashCode(self) -> int: ...
    def toString(self) -> str: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

    class Builder(java.lang.Object):
        def __init__(self) -> None: ...
        def build(self) -> AdFilters: ...
        def setAppInstallFilters(self, appInstallFilters: AppInstallFilters, /) -> AdFilters.Builder: ...
        def setFrequencyCapFilters(self, frequencyCapFilters: FrequencyCapFilters, /) -> AdFilters.Builder: ...

class AdSelectionSignals(android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[AdSelectionSignals]] = ...
    EMPTY: typing.ClassVar[AdSelectionSignals] = ...
    def describeContents(self) -> int: ...
    def equals(self, o: java.lang.Object | int | bool | float | str, /) -> bool: ...
    @staticmethod
    def fromString(source: str | java.lang.String, /) -> AdSelectionSignals: ...
    def hashCode(self) -> int: ...
    def toString(self) -> str: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

_AdServicesOutcomeReceiver__R = typing.TypeVar('_AdServicesOutcomeReceiver__R')  # <R>
_AdServicesOutcomeReceiver__E = typing.TypeVar('_AdServicesOutcomeReceiver__E', bound=java.lang.Throwable)  # <E>
class AdServicesOutcomeReceiver(java.lang.Object, typing.Generic[_AdServicesOutcomeReceiver__R, _AdServicesOutcomeReceiver__E]):
    def onError(self, error: _AdServicesOutcomeReceiver__E, /) -> None: ...
    def onResult(self, arg1: _AdServicesOutcomeReceiver__R, /) -> None: ...

class AdServicesPermissions(java.lang.Object):
    ACCESS_ADSERVICES_AD_ID: typing.ClassVar[str] = ...
    ACCESS_ADSERVICES_AD_SELECTION: typing.ClassVar[str] = ...
    ACCESS_ADSERVICES_ATTRIBUTION: typing.ClassVar[str] = ...
    ACCESS_ADSERVICES_CUSTOM_AUDIENCE: typing.ClassVar[str] = ...
    ACCESS_ADSERVICES_PROTECTED_SIGNALS: typing.ClassVar[str] = ...
    ACCESS_ADSERVICES_TOPICS: typing.ClassVar[str] = ...

class AdTechIdentifier(android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[AdTechIdentifier]] = ...
    def describeContents(self) -> int: ...
    def equals(self, o: java.lang.Object | int | bool | float | str, /) -> bool: ...
    @staticmethod
    def fromString(source: str | java.lang.String, /) -> AdTechIdentifier: ...
    def hashCode(self) -> int: ...
    def toString(self) -> str: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

class AppInstallFilters(android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[AppInstallFilters]] = ...
    def describeContents(self) -> int: ...
    def equals(self, o: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def getPackageNames(self) -> java.util.Set[java.lang.String]: ...
    def hashCode(self) -> int: ...
    def toString(self) -> str: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

    class Builder(java.lang.Object):
        def __init__(self) -> None: ...
        def build(self) -> AppInstallFilters: ...
        def setPackageNames(self, packageNames: java.util.Set[java.lang.String], /) -> AppInstallFilters.Builder: ...

class ComponentAdData(android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[ComponentAdData]] = ...
    def __init__(self, renderUri: android.net.Uri, adRenderId: str | java.lang.String, /) -> None: ...
    def describeContents(self) -> int: ...
    def equals(self, o: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def getAdRenderId(self) -> str: ...
    def getRenderUri(self) -> android.net.Uri: ...
    def hashCode(self) -> int: ...
    def toString(self) -> str: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

class FrequencyCapFilters(android.os.Parcelable):
    AD_EVENT_TYPE_CLICK: typing.ClassVar[int] = ...
    AD_EVENT_TYPE_IMPRESSION: typing.ClassVar[int] = ...
    AD_EVENT_TYPE_VIEW: typing.ClassVar[int] = ...
    AD_EVENT_TYPE_WIN: typing.ClassVar[int] = ...
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[FrequencyCapFilters]] = ...
    def describeContents(self) -> int: ...
    def equals(self, o: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def getKeyedFrequencyCapsForClickEvents(self) -> java.util.List[KeyedFrequencyCap]: ...
    def getKeyedFrequencyCapsForImpressionEvents(self) -> java.util.List[KeyedFrequencyCap]: ...
    def getKeyedFrequencyCapsForViewEvents(self) -> java.util.List[KeyedFrequencyCap]: ...
    def getKeyedFrequencyCapsForWinEvents(self) -> java.util.List[KeyedFrequencyCap]: ...
    def hashCode(self) -> int: ...
    def toString(self) -> str: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

    class Builder(java.lang.Object):
        def __init__(self) -> None: ...
        def build(self) -> FrequencyCapFilters: ...
        def setKeyedFrequencyCapsForClickEvents(self, keyedFrequencyCapsForClickEvents: java.util.List[KeyedFrequencyCap], /) -> FrequencyCapFilters.Builder: ...
        def setKeyedFrequencyCapsForImpressionEvents(self, keyedFrequencyCapsForImpressionEvents: java.util.List[KeyedFrequencyCap], /) -> FrequencyCapFilters.Builder: ...
        def setKeyedFrequencyCapsForViewEvents(self, keyedFrequencyCapsForViewEvents: java.util.List[KeyedFrequencyCap], /) -> FrequencyCapFilters.Builder: ...
        def setKeyedFrequencyCapsForWinEvents(self, keyedFrequencyCapsForWinEvents: java.util.List[KeyedFrequencyCap], /) -> FrequencyCapFilters.Builder: ...

class KeyedFrequencyCap(android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[KeyedFrequencyCap]] = ...
    def describeContents(self) -> int: ...
    def equals(self, o: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def getAdCounterKey(self) -> int: ...
    def getInterval(self) -> java.time.Duration: ...
    def getMaxCount(self) -> int: ...
    def hashCode(self) -> int: ...
    def toString(self) -> str: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

    class Builder(java.lang.Object):
        def __init__(self, adCounterKey: int | java.jint | java.lang.Integer, maxCount: int | java.jint | java.lang.Integer, interval: java.time.Duration, /) -> None: ...
        def build(self) -> KeyedFrequencyCap: ...
        def setAdCounterKey(self, adCounterKey: int | java.jint | java.lang.Integer, /) -> KeyedFrequencyCap.Builder: ...
        def setInterval(self, interval: java.time.Duration, /) -> KeyedFrequencyCap.Builder: ...
        def setMaxCount(self, maxCount: int | java.jint | java.lang.Integer, /) -> KeyedFrequencyCap.Builder: ...



import typing

import java
import java.chaquopy
import java.io
import java.lang
import java.util

class AbstractPreferences(Preferences):
    lock: java.lang.Object = ...
    newNode: bool = ...
    def __init__(self, parent: AbstractPreferences, name: str | java.lang.String, /) -> None: ...
    def absolutePath(self) -> str: ...
    def addNodeChangeListener(self, ncl: NodeChangeListener, /) -> None: ...
    def addPreferenceChangeListener(self, pcl: PreferenceChangeListener, /) -> None: ...
    def cachedChildren(self) -> java.chaquopy.JavaArray[AbstractPreferences]: ...
    def childSpi(self, arg1: str | java.lang.String, /) -> AbstractPreferences: ...
    def childrenNames(self) -> java.chaquopy.JavaArray[java.lang.String]: ...
    def childrenNamesSpi(self) -> java.chaquopy.JavaArray[java.lang.String]: ...
    def clear(self) -> None: ...
    def exportNode(self, os: java.io.OutputStream, /) -> None: ...
    def exportSubtree(self, os: java.io.OutputStream, /) -> None: ...
    def flush(self) -> None: ...
    def flushSpi(self) -> None: ...
    def get(self, key: str | java.lang.String, def_: str | java.lang.String, /) -> str: ...
    def getBoolean(self, key: str | java.lang.String, def_: bool | java.jboolean | java.lang.Boolean, /) -> bool: ...
    def getByteArray(self, key: str | java.lang.String, def_: java.chaquopy.JavaArrayJByte, /) -> java.chaquopy.JavaArrayJByte: ...
    def getChild(self, nodeName: str | java.lang.String, /) -> AbstractPreferences: ...
    def getDouble(self, key: str | java.lang.String, def_: float | java.jdouble | java.lang.Double, /) -> float: ...
    def getFloat(self, key: str | java.lang.String, def_: float | java.jfloat | java.lang.Float, /) -> float: ...
    def getInt(self, key: str | java.lang.String, def_: int | java.jint | java.lang.Integer, /) -> int: ...
    def getLong(self, key: str | java.lang.String, def_: int | java.jlong | java.lang.Long, /) -> int: ...
    def getSpi(self, arg1: str | java.lang.String, /) -> str: ...
    def isRemoved(self) -> bool: ...
    def isUserNode(self) -> bool: ...
    def keys(self) -> java.chaquopy.JavaArray[java.lang.String]: ...
    def keysSpi(self) -> java.chaquopy.JavaArray[java.lang.String]: ...
    def name(self) -> str: ...
    def node(self, path: str | java.lang.String, /) -> Preferences: ...
    def nodeExists(self, path: str | java.lang.String, /) -> bool: ...
    def parent(self) -> Preferences: ...
    def put(self, key: str | java.lang.String, value: str | java.lang.String, /) -> None: ...
    def putBoolean(self, key: str | java.lang.String, value: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def putByteArray(self, key: str | java.lang.String, value: java.chaquopy.JavaArrayJByte, /) -> None: ...
    def putDouble(self, key: str | java.lang.String, value: float | java.jdouble | java.lang.Double, /) -> None: ...
    def putFloat(self, key: str | java.lang.String, value: float | java.jfloat | java.lang.Float, /) -> None: ...
    def putInt(self, key: str | java.lang.String, value: int | java.jint | java.lang.Integer, /) -> None: ...
    def putLong(self, key: str | java.lang.String, value: int | java.jlong | java.lang.Long, /) -> None: ...
    def putSpi(self, arg1: str | java.lang.String, arg2: str | java.lang.String, /) -> None: ...
    def remove(self, key: str | java.lang.String, /) -> None: ...
    def removeNode(self) -> None: ...
    def removeNodeChangeListener(self, ncl: NodeChangeListener, /) -> None: ...
    def removeNodeSpi(self) -> None: ...
    def removePreferenceChangeListener(self, pcl: PreferenceChangeListener, /) -> None: ...
    def removeSpi(self, arg1: str | java.lang.String, /) -> None: ...
    def sync(self) -> None: ...
    def syncSpi(self) -> None: ...
    def toString(self) -> str: ...

class BackingStoreException(java.lang.Exception):
    @typing.overload
    def __init__(self, s: str | java.lang.String, /) -> None: ...
    @typing.overload
    def __init__(self, cause: java.lang.Throwable, /) -> None: ...

class InvalidPreferencesFormatException(java.lang.Exception):
    @typing.overload
    def __init__(self, message: str | java.lang.String, /) -> None: ...
    @typing.overload
    def __init__(self, cause: java.lang.Throwable, /) -> None: ...
    @typing.overload
    def __init__(self, message: str | java.lang.String, cause: java.lang.Throwable, /) -> None: ...

class NodeChangeEvent(java.util.EventObject):
    def __init__(self, parent: Preferences, child: Preferences, /) -> None: ...
    def getChild(self) -> Preferences: ...
    def getParent(self) -> Preferences: ...

class NodeChangeListener(java.util.EventListener):
    def childAdded(self, arg1: NodeChangeEvent, /) -> None: ...
    def childRemoved(self, arg1: NodeChangeEvent, /) -> None: ...

class PreferenceChangeEvent(java.util.EventObject):
    def __init__(self, node: Preferences, key: str | java.lang.String, newValue: str | java.lang.String, /) -> None: ...
    def getKey(self) -> str: ...
    def getNewValue(self) -> str: ...
    def getNode(self) -> Preferences: ...

class PreferenceChangeListener(java.util.EventListener):
    def preferenceChange(self, arg1: PreferenceChangeEvent, /) -> None: ...

class Preferences(java.lang.Object):
    MAX_KEY_LENGTH: typing.ClassVar[int] = ...
    MAX_NAME_LENGTH: typing.ClassVar[int] = ...
    MAX_VALUE_LENGTH: typing.ClassVar[int] = ...
    def __init__(self) -> None: ...
    def absolutePath(self) -> str: ...
    def addNodeChangeListener(self, arg1: NodeChangeListener, /) -> None: ...
    def addPreferenceChangeListener(self, arg1: PreferenceChangeListener, /) -> None: ...
    def childrenNames(self) -> java.chaquopy.JavaArray[java.lang.String]: ...
    def clear(self) -> None: ...
    def exportNode(self, arg1: java.io.OutputStream, /) -> None: ...
    def exportSubtree(self, arg1: java.io.OutputStream, /) -> None: ...
    def flush(self) -> None: ...
    def get(self, arg1: str | java.lang.String, arg2: str | java.lang.String, /) -> str: ...
    def getBoolean(self, arg1: str | java.lang.String, arg2: bool | java.jboolean | java.lang.Boolean, /) -> bool: ...
    def getByteArray(self, arg1: str | java.lang.String, arg2: java.chaquopy.JavaArrayJByte, /) -> java.chaquopy.JavaArrayJByte: ...
    def getDouble(self, arg1: str | java.lang.String, arg2: float | java.jdouble | java.lang.Double, /) -> float: ...
    def getFloat(self, arg1: str | java.lang.String, arg2: float | java.jfloat | java.lang.Float, /) -> float: ...
    def getInt(self, arg1: str | java.lang.String, arg2: int | java.jint | java.lang.Integer, /) -> int: ...
    def getLong(self, arg1: str | java.lang.String, arg2: int | java.jlong | java.lang.Long, /) -> int: ...
    @staticmethod
    def importPreferences(is_: java.io.InputStream, /) -> None: ...
    def isUserNode(self) -> bool: ...
    def keys(self) -> java.chaquopy.JavaArray[java.lang.String]: ...
    def name(self) -> str: ...
    def node(self, arg1: str | java.lang.String, /) -> Preferences: ...
    def nodeExists(self, arg1: str | java.lang.String, /) -> bool: ...
    def parent(self) -> Preferences: ...
    def put(self, arg1: str | java.lang.String, arg2: str | java.lang.String, /) -> None: ...
    def putBoolean(self, arg1: str | java.lang.String, arg2: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def putByteArray(self, arg1: str | java.lang.String, arg2: java.chaquopy.JavaArrayJByte, /) -> None: ...
    def putDouble(self, arg1: str | java.lang.String, arg2: float | java.jdouble | java.lang.Double, /) -> None: ...
    def putFloat(self, arg1: str | java.lang.String, arg2: float | java.jfloat | java.lang.Float, /) -> None: ...
    def putInt(self, arg1: str | java.lang.String, arg2: int | java.jint | java.lang.Integer, /) -> None: ...
    def putLong(self, arg1: str | java.lang.String, arg2: int | java.jlong | java.lang.Long, /) -> None: ...
    def remove(self, arg1: str | java.lang.String, /) -> None: ...
    def removeNode(self) -> None: ...
    def removeNodeChangeListener(self, arg1: NodeChangeListener, /) -> None: ...
    def removePreferenceChangeListener(self, arg1: PreferenceChangeListener, /) -> None: ...
    def sync(self) -> None: ...
    @staticmethod
    def systemNodeForPackage(c: typing.Type[java.lang.Object], /) -> Preferences: ...
    @staticmethod
    def systemRoot() -> Preferences: ...
    def toString(self) -> str: ...
    @staticmethod
    def userNodeForPackage(c: typing.Type[java.lang.Object], /) -> Preferences: ...
    @staticmethod
    def userRoot() -> Preferences: ...

class PreferencesFactory(java.lang.Object):
    def systemRoot(self) -> Preferences: ...
    def userRoot(self) -> Preferences: ...



import typing

import java
import java.lang

class Effect(java.lang.Object):
    def __init__(self) -> None: ...
    def apply(self, arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: int | java.jint | java.lang.Integer, arg4: int | java.jint | java.lang.Integer, /) -> None: ...
    def getName(self) -> str: ...
    def release(self) -> None: ...
    def setParameter(self, arg1: str | java.lang.String, arg2: java.lang.Object | int | bool | float | str, /) -> None: ...
    def setUpdateListener(self, listener: EffectUpdateListener, /) -> None: ...

class EffectContext(java.lang.Object):
    @staticmethod
    def createWithCurrentGlContext() -> EffectContext: ...
    def getFactory(self) -> EffectFactory: ...
    def release(self) -> None: ...

class EffectFactory(java.lang.Object):
    EFFECT_AUTOFIX: typing.ClassVar[str] = ...
    EFFECT_BACKDROPPER: typing.ClassVar[str] = ...
    EFFECT_BITMAPOVERLAY: typing.ClassVar[str] = ...
    EFFECT_BLACKWHITE: typing.ClassVar[str] = ...
    EFFECT_BRIGHTNESS: typing.ClassVar[str] = ...
    EFFECT_CONTRAST: typing.ClassVar[str] = ...
    EFFECT_CROP: typing.ClassVar[str] = ...
    EFFECT_CROSSPROCESS: typing.ClassVar[str] = ...
    EFFECT_DOCUMENTARY: typing.ClassVar[str] = ...
    EFFECT_DUOTONE: typing.ClassVar[str] = ...
    EFFECT_FILLLIGHT: typing.ClassVar[str] = ...
    EFFECT_FISHEYE: typing.ClassVar[str] = ...
    EFFECT_FLIP: typing.ClassVar[str] = ...
    EFFECT_GRAIN: typing.ClassVar[str] = ...
    EFFECT_GRAYSCALE: typing.ClassVar[str] = ...
    EFFECT_LOMOISH: typing.ClassVar[str] = ...
    EFFECT_NEGATIVE: typing.ClassVar[str] = ...
    EFFECT_POSTERIZE: typing.ClassVar[str] = ...
    EFFECT_REDEYE: typing.ClassVar[str] = ...
    EFFECT_ROTATE: typing.ClassVar[str] = ...
    EFFECT_SATURATE: typing.ClassVar[str] = ...
    EFFECT_SEPIA: typing.ClassVar[str] = ...
    EFFECT_SHARPEN: typing.ClassVar[str] = ...
    EFFECT_STRAIGHTEN: typing.ClassVar[str] = ...
    EFFECT_TEMPERATURE: typing.ClassVar[str] = ...
    EFFECT_TINT: typing.ClassVar[str] = ...
    EFFECT_VIGNETTE: typing.ClassVar[str] = ...
    def createEffect(self, effectName: str | java.lang.String, /) -> Effect: ...
    @staticmethod
    def isEffectSupported(effectName: str | java.lang.String, /) -> bool: ...

class EffectUpdateListener(java.lang.Object):
    def onEffectUpdated(self, arg1: Effect, arg2: java.lang.Object | int | bool | float | str, /) -> None: ...
